@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2003-2004 the xine project
+ * Copyright (C) 2003-2005 the xine project
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: script_engine.c,v 1.40 2004/12/13 21:19:23 dsalt Exp $
+ * $Id: script_engine.c,v 1.42 2005/01/12 02:45:37 dsalt Exp $
  *
  * gate to the spider monkey javascript interpreter
  *
@@ -107,10 +107,15 @@ static JSBool controls_exit (JSContext *cx, JSObject *obj, uintN argc,
 
 #if 0
   stop_server();
-
   printf ("script_engine: server stopped\n");
 #endif
 
+  if (gtk_main_level() < 1)
+  {
+    engine_exec ("settings_clear ();", NULL, NULL);
+    exit (2);
+  }
+
   mm_save (); 
   playlist_save (NULL);
   save_key_bindings ();
@@ -163,7 +168,8 @@ static JSBool show_about (JSContext *cx, JSObject *obj, uintN argc,
 	"A GTK media player frontend for xine\n"
 	"\n"
 	"© 2002-2004 Guenter Bartsch\n"
-	"and the xine project team\n");
+	"© 2004-2005 Darren Salt\n"
+	"© 2002-2005 the xine project team\n");
     static gchar *content = NULL;
 
     GtkWidget *layout, *text;
@@ -197,7 +203,7 @@ static JSBool show_about (JSContext *cx, JSObject *obj, uintN argc,
 
     g_signal_connect (GTK_OBJECT(about), "response",
 		      G_CALLBACK(about_cb), NULL);
-    g_signal_connect (GTK_OBJECT(about), "delete_event",
+    g_signal_connect (GTK_OBJECT(about), "delete-event",
 		      G_CALLBACK(about_cb), NULL);
   }
 
